%define major 2
%define minor 4.2
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

# (cg) Should be same version and rel + 1 as module-init-tools.
%define tools_ver 3.7
%define tools_rel 1

%bcond_without testsuite
%bcond_without tools

Summary: Kernel modules management tools
Name: 	 kmod
Version: 32
Release: %mkrel 1
Source0: https://git.kernel.org/pub/scm/utils/kernel/%{name}/%{name}.git/snapshot/%{name}-%{version}.tar.gz
Patch0: kmod32-already-have-compat-symlinks.patch
Patch1: kmod31-doc-fix-build.patch

%if %{with tools}
Source2:  modprobe.default
Source3:  modprobe.preload
Source4:  blacklist-mdv.conf
Source5:  ipw-no-associate.conf
Source6:  blacklist-compat.conf
Source7:  usb.conf
Source8:  generate-modprobe.conf
Source9:  snd-options.conf
Source10: bonding.conf
Source11: snd-intel-dspcfg.conf
Source12: amd64-microcode-blacklist.conf
Source13: intel-microcode-blacklist.conf
%endif

License: GPLv2+
Group: 	 System/Kernel and hardware
Url:	 http://git.kernel.org/cgit/utils/kernel/kmod/kmod.git

BuildRequires: pkgconfig(zlib)
BuildRequires: pkgconfig(openssl)
BuildRequires: %{_lib}zstd-devel
BuildRequires: %{_lib}lzma-devel
BuildRequires: xsltproc
BuildRequires: gtk-doc
Requires: dkms
Requires(pre): filesystem

%if %{with tools}
Provides: module-init-tools = %{tools_ver}-%{tools_rel}
Obsoletes: module-init-tools < %{tools_ver}-%{tools_rel}
%endif
# the following stuff can be removed once ldetect gets updated
############# transitional start #############################
#*************************************************************
%if 0%{__isa_bits} == 64
Provides: libmodprobe.so.0()(64bit) = %{tools_ver}-%{tools_rel}
Obsoletes: libmodprobe0.so.0()(64bit) < %{tools_ver}-%{tools_rel}
%else
Provides: libmodprobe0 = %{tools_ver}-%{tools_rel}
Obsoletes: libmodprobe0 < %{tools_ver}-%{tools_rel}
%endif
Obsoletes:  %{_lib}modprobe-devel < %{tools_ver}-%{tools_rel}
#*************************************************************
############# transitional end ###############################

Provides:	%{libname} = %{version}-%{release}

%description
Simple tools for managing kernel modules.
    provide a proper libmodprobe.so from module-init-tools:
    Early boot tools, installers, driver install disks want to access
    information about available modules to optimize boot up handling.

%package -n %{develname}
Summary:	Development files for %{name}
Group:		Development/Libraries
Requires(pre):	filesystem
Requires:	%{libname} = %{version}-%{release}
Requires:   %{_lib}lzma-devel
Requires:   %{_lib}openssl-devel
Provides:	%{name}-devel = %{version}-%{release}
Provides:   modprobe-devel = %{tools_ver}-%{tools_rel}
Obsoletes:  modprobe-devel < %{tools_ver}-%{tools_rel}
License:	LGPLv2+

%description -n %{develname}
Development files and headers for %{name}.

%prep
%setup -q
%autopatch -p1

%build
pushd testsuite
chmod a+x setup-rootfs.sh
popd
autoreconf -fiv
%configure2_5x \
	--with-xz \
	--with-zstd \
	--with-zlib \
	--with-openssl \
	--bindir=/bin \
	%if %{without testsuite}
    --disable-test-modules \
    %else
    --enable-test-modules \
    %endif
	--enable-debug 
%make_build

%install
%makeinstall_std
rm -f %{buildroot}/%_libdir/libkmod.la
rm -f %{buildroot}/bin/kmod-*
%if %{with tools}
# kmod-compat
install -d -m755 $RPM_BUILD_ROOT/{bin,sbin}
for i in depmod insmod lsmod modinfo modprobe rmmod; do
    ln -s /bin/kmod %{buildroot}/sbin/$i
done;
# (tpg) install config files
install -d -m755 %{buildroot}%{_sysconfdir}
install -d -m755 %{buildroot}%{_sysconfdir}/depmod.d
install -d -m755 %{buildroot}%{_sysconfdir}/modprobe.d
install -d -m755 %{buildroot}/lib/modprobe.d
install -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/modprobe.d/00_modprobe.conf
install -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}
install -m 755 %{SOURCE8} %{buildroot}/sbin
install -m 644 %{SOURCE4} %{SOURCE5} %{SOURCE6} %{SOURCE7} %{SOURCE9} %{SOURCE10} %{SOURCE11} %{SOURCE12} %{SOURCE13} %{buildroot}%{_sysconfdir}/modprobe.d
touch %{buildroot}%{_sysconfdir}/modprobe.conf
%else
  rm -rf %{buildroot}%{_mandir}
%endif
ln -sf %{_libdir}/lib%{name}.so.%{major}.%{minor} %{buildroot}/%{_libdir}/libmodprobe.so.0

%files
/bin/%{name}
%if %{with tools}
%dir /etc/depmod.d/
%config(noreplace) %{_sysconfdir}/modprobe.preload
%config(noreplace) %{_sysconfdir}/modprobe.conf
%dir %{_sysconfdir}/modprobe.d/
%{_sysconfdir}/modprobe.d/*.conf
/sbin/*
%_mandir/*/*
%_datadir/bash-completion/completions/kmod
%endif

%_libdir/libkmod.so.%{major}*
%_libdir/libmodprobe.so.0

%files -n %{develname}
%_libdir/pkgconfig/libkmod.pc
%_libdir/pkgconfig/kmod.pc
%_includedir/libkmod.h
%_libdir/*.so

%pre
rm -f /etc/modprobe.d/blacklist-mdv.conf
rm -f /etc/modprobe.d/snd-options.conf
rm -f  /etc/modprobe.d/00_modprobe.conf

%post
if [ ! -s /etc/modprobe.conf ]; then
	MODPROBE_CONF=/etc/modprobe.conf
elif [ -e /etc/modprobe.conf.rpmnew ]; then
	MODPROBE_CONF=/etc/modprobe.conf.rpmnew
fi

if [ -s /etc/modules.conf -a -n "$MODPROBE_CONF" ]; then
	echo '# This file is autogenerated from /etc/modules.conf using generate-modprobe.conf command' >> $MODPROBE_CONF
	echo >> $MODPROBE_CONF
	/sbin/generate-modprobe.conf >> $MODPROBE_CONF 2> /dev/null
fi

if [ -s /etc/modprobe.conf ]; then
	perl -pi -e 's/(^\s*include\s.*modprobe\.(default|compat).*)/# This file is now included automatically by modprobe\n# $1/' /etc/modprobe.conf
fi

# clean any leftover dir(s) found in /lib/modules then
# refresh modules and initrds to fit with kmod
find /lib/modules -mindepth 1 -maxdepth 1 -type d -empty -print0 | xargs -0 -I {} /bin/rmdir "{}"
for i in $(/bin/ls /lib/modules); do
    /bin/rpm -qf "/lib/modules/$i" &> /dev/null
    if [ $? -eq 0 ]; then
        echo "sync linux $i modules and rebuild the initrd-$i.img.."
        /sbin/depmod $i &> /dev/null
        /sbin/mkinitrd -f -v /boot/initrd-$i.img $i &> /dev/null
    else
        rm -fr "/lib/modules/$i"
    fi
done
echo "done"

/sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT

%if %{with testsuite}
%check
make check FAKE_BUILD=1
%endif

%changelog
* Wed Mar 13 2024 yodelu - 32-1pclos2024
- version update  

* Fri Jan 26 2024 yodelu - 31-2pclos2024
- clean leftover dir(s) found in /lib/modules
- remove %%postun script  

* Mon Oct 1 2023 yodelu - 31-1pclos2023
- update version
